@@ -485,18 +485,25 @@ sub _ansible_available_packages {
         die("no package manager");
     }
 
-    my $pkgs;
+    my $cmd;
     if($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'yum') {
-        (undef, $pkgs) = _remote_cmd($c, $peer, 'yum search omd- 2>/dev/null');
+        $cmd = 'yum search omd- 2>/dev/null';
     } elsif($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'dnf') {
-        (undef, $pkgs) = _remote_cmd($c, $peer, 'dnf search omd- 2>/dev/null');
+        $cmd = 'dnf search omd- 2>/dev/null';
     } elsif($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'apt') {
-        (undef, $pkgs) = _remote_cmd($c, $peer, 'apt-cache search omd- 2>/dev/null');
+        $cmd = 'apt-cache search omd- 2>/dev/null';
     } else {
         die("unknown package manager: ".$facts->{'ansible_facts'}->{'ansible_pkg_mgr'}//'none');
     }
+
+    my($rc, $pkgs) = _remote_cmd_background_wait($c, $peer, $cmd, undef, undef, 180, "updating available packages");
+    if($rc != 0) {
+        _debug("fetching available packages failed: %s", ($pkgs || 'unknown error'));
+        return({});
+    }
+
     my @pkgs = ($pkgs =~ m/^(omd\-\S+?)(?:\s|\.x86_64|\.aarch64)/gmx);
-    @pkgs = grep(!/^(omd-labs-edition|omd-daily|.*-addons-|.*-meta\.)/mx, @pkgs); # remove meta packages
+    @pkgs = grep(!/^(omd-labs-edition|omd-daily|omd-stream|.*-addons-|.*-meta\.)/mx, @pkgs); # remove meta packages
     @pkgs = reverse sort @pkgs;
     @pkgs = map { my $pkg = $_; $pkg =~ s/^omd\-//gmx; $pkg; } @pkgs;
 
@@ -514,7 +521,7 @@ sub _ansible_available_os_updates {
     my $updates  = [];
     my $security = [];
     if($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'apt') {
-        my($rc, $out) = _remote_cmd($c, $peer, 'apt-get -y --dry-run upgrade');
+        my($rc, $out) = _remote_cmd_background_wait($c, $peer, 'apt-get -y --dry-run upgrade', undef, undef, 180, "dry run upgrade");
         if($rc == 0) {
             my @updates = $out =~ m/^Inst\s+(\S+)\s+(.*)$/gmx;
             while(scalar @updates > 0) {
@@ -530,18 +537,18 @@ sub _ansible_available_os_updates {
     }
 
     if($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'dnf') {
-        my($rc, $out) = _remote_cmd($c, $peer, 'dnf check-update 2>/dev/null');
+        my($rc, $out) = _remote_cmd_background_wait($c, $peer, 'dnf check-update 2>/dev/null', undef, undef, 180, "dnf check-update");
         $updates = _parse_yum_check_update($out);
 
-        ($rc, $out) = _remote_cmd($c, $peer, 'dnf check-update --security 2>/dev/null');
+        ($rc, $out) = _remote_cmd_background_wait($c, $peer, 'dnf check-update --security 2>/dev/null', undef, undef, 180, "dnf check security update");
         $security = _parse_yum_check_update($out);
     }
 
     if($facts->{'ansible_facts'}->{'ansible_pkg_mgr'} eq 'yum') {
-        my($rc, $out) = _remote_cmd($c, $peer, 'yum check-update 2>/dev/null');
+        my($rc, $out) = _remote_cmd_background_wait($c, $peer, 'yum check-update 2>/dev/null', undef, undef, 180, "yum check-update");
         $updates = _parse_yum_check_update($out);
 
-        ($rc, $out) = _remote_cmd($c, $peer, 'yum check-update --security 2>/dev/null');
+        ($rc, $out) = _remote_cmd_background_wait($c, $peer, 'yum check-update --security 2>/dev/null', undef, undef, 180, "yum check security update");
         $security = _parse_yum_check_update($out);
     }
 
@@ -1038,6 +1045,33 @@ sub _remote_cmd {
     return(_ansible_cmd($c, $peer, $fullcmd, $background_options, $err));
 }
 
+##########################################################
+# run command on remote machine in background but wait for completion
+sub _remote_cmd_background_wait {
+    my($c, $peer, $cmd, $background_options, $env, $max_wait, $msg) = @_;
+    $background_options = {} unless defined $background_options;
+    $max_wait           = 1800 unless $max_wait;
+
+    $background_options->{'message'} = $msg;
+
+    my($rc, $job);
+    eval {
+        ($rc, $job) = _remote_cmd($c, $peer, $cmd, $background_options, $env);
+    };
+    my $err = $@;
+    if($err) {
+        return(1, "remote job failed to start: ".$err);
+    }
+
+    # wait for $max_wait seconds
+    my $jobdata = Thruk::Utils::External::wait_for_peer_job($c, $peer, $job, 2, $max_wait, 1);
+    if(!$jobdata) {
+        return(1, "remote job ".$job." failed for unknown reason");
+    }
+
+    return($jobdata->{'rc'}, $jobdata->{'stdout'});
+}
+
 ##########################################################
 # run cmd via ssh
 sub _ssh_cmd {
@@ -1641,6 +1675,7 @@ sub clean_old_json_files {
     my($c, $peers) = @_;
 
     $c->stats->profile(begin => "clean_old_json_files");
+    my $delete_threshold_date = time() - (7*86400);
 
     my $keys = {};
     for my $peer (@{$peers}) {
@@ -1651,7 +1686,13 @@ sub clean_old_json_files {
         $f = Thruk::Base::basename($f);
         $f =~ s/\.json$//gmx;
         next if $f eq '_conf';
-        unlink($c->config->{'var_path'}.'/node_control/'.$f.'.json') unless $keys->{$f};
+        if(!$keys->{$f}) {
+            my $file = $c->config->{'var_path'}.'/node_control/'.$f.'.json';
+            my @stat = stat($file);
+            if($stat[9] < $delete_threshold_date) {
+                unlink($file);
+            }
+        }
     }
 
     $c->stats->profile(end => "clean_old_json_files");
